summaryrefslogtreecommitdiffstats
path: root/src/core/hle/service/apm/apm_controller.h
diff options
context:
space:
mode:
authorNarr the Reg <juangerman-13@hotmail.com>2022-02-21 23:01:20 +0100
committerNarr the Reg <juangerman-13@hotmail.com>2022-02-22 01:00:50 +0100
commitd44464829ba4448a51c199be893840b33903c489 (patch)
tree0dc25d8e699784cd53610ee26106d3fab8dfe77b /src/core/hle/service/apm/apm_controller.h
parentMerge pull request #7913 from voidanix/anv-fix (diff)
downloadyuzu-d44464829ba4448a51c199be893840b33903c489.tar
yuzu-d44464829ba4448a51c199be893840b33903c489.tar.gz
yuzu-d44464829ba4448a51c199be893840b33903c489.tar.bz2
yuzu-d44464829ba4448a51c199be893840b33903c489.tar.lz
yuzu-d44464829ba4448a51c199be893840b33903c489.tar.xz
yuzu-d44464829ba4448a51c199be893840b33903c489.tar.zst
yuzu-d44464829ba4448a51c199be893840b33903c489.zip
Diffstat (limited to '')
-rw-r--r--src/core/hle/service/apm/apm_controller.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/src/core/hle/service/apm/apm_controller.h b/src/core/hle/service/apm/apm_controller.h
index 8d48e0104..d6fbd2c0c 100644
--- a/src/core/hle/service/apm/apm_controller.h
+++ b/src/core/hle/service/apm/apm_controller.h
@@ -32,15 +32,18 @@ enum class PerformanceConfiguration : u32 {
Config16 = 0x9222000C,
};
+// This is nn::oe::CpuBoostMode
enum class CpuBoostMode : u32 {
- Disabled = 0,
- Full = 1, // CPU + GPU -> Config 13, 14, 15, or 16
- Partial = 2, // GPU Only -> Config 15 or 16
+ Normal = 0, // Boost mode disabled
+ FastLoad = 1, // CPU + GPU -> Config 13, 14, 15, or 16
+ Partial = 2, // GPU Only -> Config 15 or 16
};
-enum class PerformanceMode : u8 {
- Handheld = 0,
- Docked = 1,
+// This is nn::oe::PerformanceMode
+enum class PerformanceMode : s32 {
+ Invalid = -1,
+ Normal = 0,
+ Boost = 1,
};
// Class to manage the state and change of the emulated system performance.